"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.show = exports.hide = exports.fadeOut = exports.fadeIn = exports.$url = exports.$toast = exports.$createElement = exports.$ajax = exports.$getJSON = exports.$canvas = exports.$audio = exports.$date = exports.$id = exports.$selectorAll = exports.$selector = exports.$body = exports.$root = void 0;
// dinamic styles
const styles = document.createElement('style');
styles.textContent = `
  .show, .hide {
    transition: opacity 400ms;
  }

  .show {
    opacity: 1;
  }
  
  .hide {
    opacity: 0;
  }
`;
document.head.appendChild(styles);
// create elements
const $createElement = (el) => document.createElement(el);
exports.$createElement = $createElement;
// root 
const $root = document.documentElement;
exports.$root = $root;
// body
const $body = document.body;
exports.$body = $body;
// query selector
const $selector = (el) => document.querySelector(el);
exports.$selector = $selector;
// selector all
const $selectorAll = (el) => document.querySelectorAll(el);
exports.$selectorAll = $selectorAll;
// selector id
const $id = (el) => document.getElementById(el);
exports.$id = $id;
// date
const $date = (date = null) => new Date(date);
exports.$date = $date;
// audio
const $audio = (path) => new Audio(path);
exports.$audio = $audio;
// canvas
const $canvas = (id) => document.querySelector(id);
exports.$canvas = $canvas;
// ajax
const $getJSON = async (url, callback) => {
    const res = await fetch(url);
    callback(await res.json());
};
exports.$getJSON = $getJSON;
const $ajax = async ({ url, type, data, headers, dataType, success, failed }) => {
    try {
        const res = await fetch(url, {
            method: type,
            body: data,
            headers,
        });
        if (!res.ok) {
            throw new Error(`HTTP error: ${res.status}`);
        }
        switch (dataType) {
            case 'text':
                success(await res.text());
                break;
            case 'json':
                success(await res.json());
                break;
            default:
                success(await res.blob());
                break;
        }
    }
    catch (err) {
        failed(err);
    }
};
exports.$ajax = $ajax;
// fade effects
const fadeIn = (el) => {
    el.classList.contains('hide')
        ? el.classList.replace('hide', 'show')
        : el.classList.add('show');
};
exports.fadeIn = fadeIn;
const fadeOut = (el) => {
    el.classList.contains('show')
        ? el.classList.replace('show', 'hide')
        : el.classList.add('hide');
};
exports.fadeOut = fadeOut;
// show and hidden elements
const hide = (el) => (el.style.display = 'none');
exports.hide = hide;
const show = (el) => (el.style.display = '');
exports.show = show;
const $toast = (msg, classAlert, time) => {
    const toast = $createElement('div');
    toast.textContent = msg;
    toast.classList.add(classAlert, 'show');
    $body.prepend(toast);
    setTimeout(() => {
        fadeOut(toast);
        $body.removeChild(toast);
    }, time);
};
exports.$toast = $toast;
const $url = (url) => new URL(url);
exports.$url = $url;
